from typing import Optional, Dict, TYPE_CHECKING

if TYPE_CHECKING:
    from gettext import gettext as _


class ConfigFile:
    def __init__(self,
                 text: str,
                 name: str = None,
                 filename: str = None,
                 gpt_support: bool = False,
                 description: str = None) -> None:
        self.__name = name
        self.__text = text
        self.__description = description
        self.__filename = filename
        self.__gpt_support = gpt_support

    @staticmethod
    def from_data(data: Dict[str, str]):  # -> LayoutConfigFile
        with open(data.get('path'), 'r') as file:
            text = file.read()

        return ConfigFile(name=data.get('name', _('Untitled')),
                          description=data.get('description'),
                          filename=data.get('filename'),
                          gpt_support=data.get('gpt_support', False),
                          text=text)

    @property
    def name(self) -> Optional[str]:
        return self.__name

    @property
    def source_text(self) -> str:
        return self.__text

    @property
    def description(self) -> Optional[str]:
        return self.__description

    @property
    def filename(self) -> Optional[str]:
        return self.__filename

    @property
    def gpt_support(self) -> bool:
        return self.__gpt_support
